# -*- coding: UTF-8 -*-
###########################################################################
# Eole NG - 2007
# Copyright Pole de Competence Eole  (Ministere Education - Academie Dijon)
# Licence CeCill  cf /root/LicenceEole.txt
# eole@ac-dijon.fr
###########################################################################

"""
Agent zephir pour la surveillance d'expiration des certificats
"""

from zephir.monitor.agentmanager.agent import Agent
from zephir.monitor.agentmanager.data import HTMLData, TableData
from zephir.monitor.agentmanager import status
from pyeole.diagnose import test_cert


class LocalCert(Agent):
    def __init__(self, name, cert_files, **params):
        Agent.__init__(self, name, **params)
        self.status = status.OK()
        self.table = TableData([
            ('path', "Chemin du certificat", {'align': 'left'}, None),
            ('expire', "Validité", {'align': 'left'}, None),
            ('usage', "Impact", {'align': 'left'}, None),
            ])
        self.cert_files = cert_files
        title = HTMLData("<h3>Surveillance des certificats</h3>")
        self.data = [title, self.table]

    def measure(self):
        self.status = status.OK()
        new_measure = []
        for cert_file in self.cert_files:
            chain = self.cert_files[cert_file]['chain'] if 'chain' in self.cert_files[cert_file] else None
            if 'type' in self.cert_files[cert_file] and self.cert_files[cert_file]['type'] == 'autosigné':
                if cert_file.startswith('/etc/ipsec.d/'):
                    ca = '/etc/ipsec.d/cacerts/CertifCa.pem'
                else:
                    ca = '/etc/ssl/certs/ca.crt'
            else:
                ca = '/etc/ssl/certs/ca-certificates.crt'
            res = test_cert(cert_file, chain, ca)
            if not res['valid'][0]:
                self.status = status.Error()
                new_measure.append({'path': cert_file,
                                    'expire': res['valid'][1],
                                    'usage': ', '.join(self.cert_files[cert_file].get('usage', [])),
                                    })
                continue
            if res['expired'][0] != 'OK':
                if res['expired'][0] == 'ERROR' and self.status < status.Error():
                    self.status = status.Error()
                elif self.status < status.Warn():  # WARNING
                    self.status = status.Warn()
                new_measure.append({'path': cert_file,
                                    'expire': res['expired'][1],
                                    'usage': ', '.join(self.cert_files[cert_file].get('usage', [])),
                                    })
                continue
            # Certificate OK
            new_measure.append({'path': cert_file,
                                'expire': res['expired'][1],
                                'usage': ', '.join(self.cert_files[cert_file].get('usage', [])),
                                })

        return new_measure

    def write_data(self):
        Agent.write_data(self)
        if self.last_measure is not None:
            self.table.table_data = self.last_measure.value

    def check_status(self):
        return self.status
